"""
Space Alignment

For each line of code, write a linear equation and solve the system.
"""
import math

SPACE = "s"
TAB = "t"


def euclid(a, b):
    if b == 0:
        return a, 1, 0
    d, y, x = euclid(b, a % b)

    return d, x, y - (a // b) * x


def main():
    n = int(input())
    depth = 0
    equations = set()
    for _ in range(n):
        line = input()
        assert line[-1] in "{}"
        spaces = line.count(SPACE)
        tabs = line.count(TAB)

        if line[-1] == "}":
            depth -= 1
        if spaces > 0 or tabs > 0:
            g = math.gcd(math.gcd(spaces, tabs), depth)
            equations.add((spaces // g, tabs // g, depth // g))

        if line[-1] == "{":
            depth += 1

    assert depth == 0

    equations = list(equations)
    if not equations:
        print(1)
    elif len(equations) == 1:
        spaces, tabs, depth = equations[0]
        g, inv, _ = euclid(tabs, depth)
        ans = -spaces * inv % depth
        if ans == 0:
            ans = depth
        if g != 1 or (spaces + tabs * ans) % depth != 0:
            print(-1)
        else:
            print(ans)
    else:
        s0, t0, d0 = equations[0]
        s1, t1, d1 = equations[1]

        # they cannot be multiples since we divide out
        # and there's no 0 entry. Just use Cramer's.

        den = d0 * t1 - t0 * d1
        if den != 0:
            x = (s0 * d1 - d0 * s1) // den
            k = (s0 * t1 - t0 * s1) // den

            if x > 0 and k > 0 and all((a + b * x) == k * d for a, b, d in equations):
                print(x)
            else:
                print(-1)
        else:
            print(-1)


if __name__ == "__main__":
    main()
